package env;

import javax.servlet.ServletConfig;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;

import org.objectweb.telosys.auth.TelosysAUTH;
import org.objectweb.telosys.common.Telosys;
import org.objectweb.telosys.common.TelosysServlet;
import org.objectweb.telosys.dal.TelosysDAL;
import org.objectweb.telosys.rpl.TelosysRPL;
import org.objectweb.telosys.uil.TelosysUIL;

/**
 * Standard startup servlet for a Telosys WebApp
 * 
 */

public class InitServlet extends TelosysServlet 
{
	private static final long serialVersionUID = -6008414304098654491L;

    //-----------------------------------------------------------------------------
    public void init() throws ServletException
    {
        try
        {

            info("===========================================================================");
            info("=== InitServlet : init()");

            ServletConfig servletConfig = getServletConfig();

            if (servletConfig == null)
            {
                error("=== InitServlet : cannot get ServletConfig : getServletConfig() returns null ! ");
                return;
            }

            printContextInfo(servletConfig);

            //=========================================================================================
            info("=== Main Factory Creation ...");

            //--- External Factory creation
            MainFactory extFactory = new MainFactory();

            //--- Try to find the Telosys Properties file
            //String sTelosysPropFile = Tool.findTelosysPropertiesFile(config);
            //info("=== Telosys properties file : " + sTelosysPropFile);

            info("=== Telosys Initialization ...");
            Telosys.init(extFactory, servletConfig);

            //--- Init the different layers
            info("=== Telosys authentication layer initialization ...");
            TelosysAUTH.init();

            info("=== Telosys U.I.L. initialization ...");
            TelosysUIL.init();

            info("=== Telosys R.P.L. initialization ...");
            TelosysRPL.init();

            info("=== Telosys D.A.L. initialization ...");
            TelosysDAL.init();

        } catch (Exception e)
        {
            error("Exception in initialization ! ");
            error("Exception = " + e.toString() + " - Message = " + e.getMessage());
            e.printStackTrace();
        } catch (Throwable t)
        {
            error("Throwable exception in initialization ! ");
            error("Throwable exception = " + t.toString() + " - Message = " + t.getMessage());
            t.printStackTrace();
        }

        info("===========================================================================");
        info(" End of Telosys initialization");
        info(" . Properties file name    = " + Telosys.getPropertiesFile());
        info(" . Configuration directory = " + Telosys.getConfigDirectory());
        info("===========================================================================");

        //=========================================================================================
        info("");
        info("===========================================================================");
        info("=== Application Data Initialization ...");
        info("===========================================================================");
        
        /*
         * Insert your specific application data initialization here
         */
        
        info("===========================================================================");
        info("=== End of Application Data Initialization");
        info("===========================================================================");
    }

    //-----------------------------------------------------------------------------
    public void destroy()
    {
        info("===========================================================================");
        info("=== TELOSYS : End of InitServlet ( destroy ) ");
        info("===========================================================================");
    }

    //-----------------------------------------------------------------------------
    private void printContextInfo(ServletConfig config)
    {
        ServletContext context = config.getServletContext();
        if (context != null)
        {
            info("=== Server Info  : " + context.getServerInfo());
            info("=== Version      : " + context.getMajorVersion() + "." + context.getMinorVersion());
            info("=== Context Name : " + context.getServletContextName());
            info("=== Real Path    : " + context.getRealPath(""));
        }
        else
        {
            info("=== Context not found ! ");
            error("Context not found");
        }
    }
}