package env;

import org.objectweb.telosys.auth.IUserValidator;
import org.objectweb.telosys.common.IExternalMainFactory;
import org.objectweb.telosys.common.TelosysObject;
import org.objectweb.telosys.rpl.xml.IXmlWrapperProvider;
import org.objectweb.telosys.rpl.xml.StandardXmlWrapperRegistry;
import org.objectweb.telosys.screen.core.IScreenDataProvider;
import org.objectweb.telosys.screen.core.IScreenProvider;
import org.objectweb.telosys.service.IServiceProvider;

/**
 * Telosys main factory
 * 
 * This class provides all the application specific components needed by Telosys 
 *  
 */
public class MainFactory extends TelosysObject implements IExternalMainFactory
{
    private static ScreenRegistry      $screenRegistry     = null;

    private static ServiceRegistry     $serviceRegistry    = null;

    private static IXmlWrapperProvider $xmlWrapperRegistry = null;

    /**
     *  
     */
    public MainFactory()
    {
        super();
        info("MainFactory creation ...");
        //--- Initialize the Screen Registry if necessary
        if ($screenRegistry == null)
        {
            info("screen registry creation ...");
            $screenRegistry = new ScreenRegistry();
        }
        //--- Initialize the Service Registry if necessary
        if ($serviceRegistry == null)
        {
            info("service registry creation ...");
            $serviceRegistry = new ServiceRegistry();
        }
        //--- Initialize the XML Wrappers Registry if necessary
        if ($xmlWrapperRegistry == null)
        {
            info("xml wrapper registry creation ...");
            $xmlWrapperRegistry = new StandardXmlWrapperRegistry();
        }
    }

    public IXmlWrapperProvider getXmlWrapperProvider()
    {
        trace("getXmlWrapperProvider()");
        return $xmlWrapperRegistry;
    }

    public IScreenDataProvider getScreenDataProvider()
    {
        trace("getScreenDataProvider()");
        return $screenRegistry;
    }

    public IScreenProvider getScreenProvider()
    {
        trace("getScreenProvider()");
        return $screenRegistry;
    }

    public IServiceProvider getServiceProvider()
    {
        trace("getServiceProvider()");
        return $serviceRegistry;
    }

    public IUserValidator getUserValidator()
    {
        trace("getUserValidator()");
        return new UserValidator();
    }
}